@@ -1,13 +1,12 @@
 //! Ockam is a library for building devices that communicate securely, privately
 //! and trustfully with cloud services and other devices.
-#![deny(
-  //  missing_docs, // not compatible with big_array
+#![deny(unsafe_code)]
+#![warn(
+    // missing_docs // not compatible with big_array
     trivial_casts,
     trivial_numeric_casts,
-    unsafe_code,
     unused_import_braces,
-    unused_qualifications,
-    warnings
+    unused_qualifications
 )]
 #![cfg_attr(not(feature = "std"), no_std)]
 
@@ -59,6 +58,7 @@ pub use protocols::*;
 pub use remote_forwarder::*;
 pub use unique::*;
 
+pub mod pipe;
 pub mod stream;
 
 pub use ockam_core::{
