@@ -1,4 +1,3 @@
-#![allow(unused)]
 use core::sync::atomic::{AtomicUsize, Ordering};
 
 /// A simple monotonic ID generator
@@ -7,8 +6,16 @@ pub(crate) struct Monotonic {
 }
 
 impl Monotonic {
+    /// Create a new monotonic ID counter from 0
     pub(crate) fn new() -> Self {
-        Monotonic { inner: 0.into() }
+        Self::from(0)
+    }
+
+    /// Create a new monotonic ID counter from a starting point
+    ///
+    /// This is useful when dealing with 1-indexed systems
+    pub(crate) fn from(u: usize) -> Self {
+        Monotonic { inner: u.into() }
     }
 
     pub(crate) fn next(&self) -> usize {
